@@ -13,6 +13,10 @@ class Color(str, Enum):
     END = '\033[0m'
 
 
+# Parses the grid of type defenses.
+# The csv file is modified from the
+# visual chart on Pokémon Database.
+# https://pokemondb.net/type
 all_type_defenses = parsing.csv_to_nested_dict(
     "pokesummary.data",
     "type_defenses_modified.csv",
@@ -57,7 +61,11 @@ def get_base_stats_chart(pokemon_stats):
         string_list.append(f"{color}{value:>4}{Color.END}")
         string_list.append(f" {'*' * (value // 5)}\n")
 
-    string_list.append(f"{'Total':<9}{Color.BOLD}{pokemon_stats['base_stat_total']:>4}{Color.END}\n")
+    string_list.append(
+        f"{'Total':<9}"
+        f"{Color.BOLD}{pokemon_stats['base_stat_total']:>4}"
+        f"{Color.END}\n"
+    )
     return "".join(string_list)
 
 
@@ -108,6 +116,14 @@ def format_multiplier(multiplier):
 
 
 def display_summary(pokemon_name, pokemon_stats):
+    """
+    Given a Pokémon's name and a dictionary of its stats,
+    format and print its classification, height, weight,
+    base stat chart, and type defenses chart.
+
+    :param pokemon_name: the name of the Pokémon
+    :param pokemon_stats: a dictionary of the Pokémon's stats
+    """
     print(
         f"{Color.BOLD}{Color.UNDERLINE}{pokemon_name.upper()}, "
         f"{pokemon_stats['classification'].upper()}{Color.END}"
@@ -117,7 +133,8 @@ def display_summary(pokemon_name, pokemon_stats):
         f"{pokemon_stats['pokemon_weight']}kg")
     print(
         f"{pokemon_stats['primary_type']}"
-        f"{', ' + pokemon_stats['secondary_type'] if pokemon_stats['secondary_type'] != '' else ''}"
+        f"{', ' if pokemon_stats['secondary_type'] != '' else ''}"
+        f"{pokemon_stats['secondary_type']}"
     )
     print()
 
